pub enum LabelDecision {
Render,
Skip,
}Expand description
A decision on whether to render or skip a tick label.
This is the output of the collision detection pass.
Variants
Render
The label does not overlap others and should be drawn.
Skip
The label overlaps a higher-priority label and should be hidden.