Interaction

Struct Interaction 

pub struct Interaction<Message: Clone, Tag = ()> { /* private fields */ }
An interactable plot-area

Examples

use iced_aksel::{Interaction, PlotPoint, Measure};
use iced_aksel::shape::Rectangle;
use iced_aksel::interaction::IntoArea;

#[derive(Debug, Clone)]
enum Message {
    RectPressed,
}

// Create a shape
let shape = Rectangle::centered(
    PlotPoint::new(50.0, 50.0),
    Measure::Plot(20.0),
    Measure::Plot(10.0),
);

// Convert shape to area and create interaction
let area = shape.resolve_area(plot);
let interaction = Interaction::new(area)
    .on_press(Message::RectPressed);

plot.render(shape);

Implementations

Source

impl<Message: Clone, Tag: Hash + Eq + Clone> Interaction<Message, Tag>

pub const fn new(area: Area) -> Self

Creates a new Interaction

pub const fn priority(self, prio: u16) -> Self

Sets the priority of the interaction.

0 = highest priority. 255 = lowest priority.

Defaults to 255.

pub fn cursor<F, Mk>(self, f: F) -> Self

Sets a dynamic cursor for this interaction based on its current status.

pub fn on_enter<H, Marker>(self, h: H) -> Self
where H: IntoHandler<Message, (Id<Tag>, EnterEvent), Marker>,

Sets the event handler for when the cursor enters the interaction

pub fn on_exit<H, Marker>(self, h: H) -> Self
where H: IntoHandler<Message, (Id<Tag>, ExitEvent), Marker>,

Sets the event handler for when the cursor enters the interaction

pub fn on_drag<H, Marker>(self, h: H) -> Self
where H: IntoHandler<Message, (Id<Tag>, DragEvent<Delta>), Marker>,

Sets the event handler for interaction dragging

pub fn on_press<H, Marker>(self, h: H) -> Self
where H: IntoHandler<Message, (Id<Tag>, PressEvent<Point>), Marker>,

Sets the event handler for interaction mouse presses

pub fn on_release<H, Marker>(self, h: H) -> Self
where H: IntoHandler<Message, (Id<Tag>, ReleaseEvent<Point>), Marker>,

Sets the event handler for interaction mouse releases