Plot

Struct Plot 

pub struct Plot<'a, D: Float, Message: Clone, Tag = (), Renderer: Renderer = Renderer> { /* private fields */ }
The plot rendering context for drawing shapes.

This is passed to your PlotData::draw implementation. Use [Plot::add_shape] to render visual elements.

Implementations

Source

impl<'a, D, Message, Tag, Renderer> Plot<'a, D, Message, Tag, Renderer>
where Message: Clone, Tag: Hash + Eq + Clone, D: Float, Renderer: Renderer,

pub fn plot_bounds(&self) -> PlotRect<D>

Returns the current plot bounds in data space.

Example
let bounds = plot.bounds();
let (x_min, x_max) = (bounds.min_x(), bounds.max_x());
let (y_min, y_max) = (bounds.min_y(), bounds.max_y());
pub fn render<S: Shape<D, Renderer>>(&mut self, shape: S)

Renders a shape to the plot.

Example
plot.add_shape(
    Ellipse::new(PlotPoint::new(5.0, 10.0), Measure::Screen(20.0), Measure::Screen(10.0))
        .fill(Color::from_rgb(1.0, 0.0, 0.0))
);
pub fn push_interaction( &mut self, id: impl Into<Id<Tag>>, interaction: impl Into<Interaction<Message, Tag>>, )

Pushes an interaction to the plot

Methods from Deref<Target = Context<'a, D, Renderer>>

pub fn default_font(&self) -> Font

Returns the default font of the underlying renderer

pub fn measure_text(&self, text: Text<&str>) -> Size

Measures a Text to get it’s bounds

pub fn clip_bounds(&self) -> Rectangle

Returns the screen bounds bounds of the plot

Methods from Deref<Target = Transform<'a, D, f32, f32>>

pub fn screen_bounds(&self) -> &ScreenRect<S>

Returns the screen rectangle bounds used by this transform.

This is the same rectangle that was passed to Transform::new.

Examples
use aksel::{Transform, scale::Linear, ScreenRect};

let screen = ScreenRect { x: 0.0, y: 0.0, width: 800.0, height: 600.0 };
let x_scale = Linear::<f64, f32>::new(0.0, 100.0);
let y_scale = Linear::<f64, f32>::new(0.0, 50.0);
let transform = Transform::new(&screen, &x_scale, &y_scale);

let bounds = transform.screen_bounds();
assert_eq!(bounds.width, 800.0);
assert_eq!(bounds.height, 600.0);
pub fn plot_bounds(&self) -> PlotRect<D>

pub fn screen_to_chart_opt( &self, screen_point: &ScreenPoint<S>, ) -> Option<PlotPoint<D>>

Transforms a point from screen coordinates to chart coordinates.

pub fn screen_to_chart(&self, screen_point: &ScreenPoint<S>) -> PlotPoint<D>

Transforms a point from screen coordinates to chart coordinates.

pub fn chart_to_screen_opt( &self, plot_point: &PlotPoint<D>, ) -> Option<ScreenPoint<S>>

Transforms a point from chart coordinates to screen coordinates.

pub fn chart_to_screen(&self, plot_point: &PlotPoint<D>) -> ScreenPoint<S>

Transforms a point from chart coordinates to screen coordinates.

pub fn x_to_screen_opt(&self, plot_x: &D) -> Option<S>

Transforms a single chart x-coordinate to a screen x-coordinate.

pub fn x_to_screen(&self, plot_x: &D) -> S

Transforms a single chart x-coordinate to a screen x-coordinate.

pub fn y_to_screen_opt(&self, plot_y: &D) -> Option<S>

Transforms a single chart y-coordinate to a screen y-coordinate. (This includes the y-axis inversion)

pub fn y_to_screen(&self, plot_y: &D) -> S

Transforms a single chart y-coordinate to a screen y-coordinate. (This includes the y-axis inversion)

pub fn x_from_screen_opt(&self, screen_x: &S) -> Option<D>

Transforms a single screen x-coordinate to a chart x-coordinate.

pub fn x_from_screen(&self, screen_x: &S) -> D

Transforms a single screen x-coordinate to a chart x-coordinate.

pub fn y_from_screen_opt(&self, screen_y: &S) -> Option<D>

Transforms a single screen y-coordinate to a chart y-coordinate. (This accounts for the y-axis inversion)

pub fn y_from_screen(&self, screen_y: &S) -> D

Transforms a single screen y-coordinate to a chart y-coordinate. (This accounts for the y-axis inversion)

pub fn screen_to_chart_rect_opt( &self, screen_rect: ScreenRect<S>, ) -> Option<PlotRect<D>>

Transforms a rectangle from screen coordinates to chart coordinates.

pub fn screen_to_chart_rect(&self, screen_rect: ScreenRect<S>) -> PlotRect<D>

Transforms a rectangle from screen coordinates to chart coordinates.

pub fn chart_to_screen_rect_opt( &self, plot_rect: PlotRect<D>, ) -> Option<ScreenRect<S>>

Transforms a rectangle from chart coordinates to screen coordinates.

pub fn chart_to_screen_rect(&self, plot_rect: PlotRect<D>) -> ScreenRect<S>

Transforms a rectangle from chart coordinates to screen coordinates.